@@ -1,11 +1,11 @@
-const readline = require('readline');
+const readline = require("readline");
 
-const Ajv = require("ajv")
+const Ajv = require("ajv");
 
 const stdio = readline.createInterface({
   input: process.stdin,
   output: process.stdout,
-  terminal: false
+  terminal: false,
 });
 
 function send(data) {
@@ -18,7 +18,16 @@ const cmds = {
   start: (args) => {
     console.assert(args.version === 1, { args });
     started = true;
-    return {ready: true, version: 1}
+    return {
+      ready: true,
+      version: 1,
+      implementation: {
+        language: "javascript",
+        name: "ajv",
+        homepage: "https://ajv.js.org/",
+        issues: "https://github.com/ajv-validator/ajv/issues",
+      },
+    };
   },
 
   run: (args) => {
@@ -28,20 +37,22 @@ const cmds = {
     const validate = ajv.compile(testCase.schema);
     return {
       seq: args.seq,
-      tests: testCase.tests.map((test) => ({ valid: validate(test.instance) }))
-    }
+      results: testCase.tests.map((test) => ({
+        valid: validate(test.instance),
+      })),
+    };
   },
 
   stop: (_) => {
-      console.assert(started, "Not started!");
-      process.exit(0);
-  }
-}
+    console.assert(started, "Not started!");
+    process.exit(0);
+  },
+};
 
 const ajv = new Ajv();
 
-stdio.on('line', (line) => {
+stdio.on("line", (line) => {
   const request = JSON.parse(line);
   const response = cmds[request.cmd](request);
   send(response);
-})
+});
